==> wicket-1.3.7-sources.jar: org/apache/wicket/util/resource/PackageResourceStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.util.resource;

import java.io.IOException;
import java.io.InputStream;

import org.apache.wicket.Application;
import org.apache.wicket.WicketRuntimeException;
import org.apache.wicket.util.lang.Packages;
import org.apache.wicket.util.resource.locator.IResourceStreamLocator;
import org.apache.wicket.util.time.Time;


/**
 * An {@link IResourceStream} that reads data from a resource in the classpath. It simply delegates
 * all operations to the {@link IResourceStream} returned by the application's
 * {@link IResourceStreamLocator}.
 * 
 * @author <a href="mailto:jbq@apache.org">Jean-Baptiste Quenot</a>
 */
public class PackageResourceStream extends AbstractResourceStream
{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	IResourceStream resourceStream;

	/**
	 * Obtains an {@link IResourceStream} from the application's
	 * {@link IResourceStreamLocator#locate(Class, String)}
	 * 
	 * @param scope
	 *            This argument will be used to get the class loader for loading the package
	 *            resource, and to determine what package it is in.
	 * @param path
	 *            The path to the resource
	 */
	public PackageResourceStream(Class scope, String path)
	{
		String absolutePath = Packages.absolutePath(scope, path);
		resourceStream = Application.get().getResourceSettings().getResourceStreamLocator().locate(
				scope, absolutePath, null, null, null);

		if (resourceStream == null)
		{
			throw new WicketRuntimeException("Cannot find resource with " + scope.getName() +
					" and path " + path);
		}
	}

	public void close() throws IOException
	{
		resourceStream.close();
	}

	public String getContentType()
	{
		return resourceStream.getContentType();
	}

	public InputStream getInputStream() throws ResourceStreamNotFoundException
	{
		return resourceStream.getInputStream();
	}

	public long length()
	{
		return resourceStream.length();
	}

	public Time lastModifiedTime()
	{
		return resourceStream.lastModifiedTime();
	}
}

==> wicket-1.4-rc4-sources.jar: org/apache/wicket/util/resource/PackageResourceStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.util.resource;

import java.io.IOException;
import java.io.InputStream;

import org.apache.wicket.Application;
import org.apache.wicket.WicketRuntimeException;
import org.apache.wicket.util.lang.Packages;
import org.apache.wicket.util.resource.locator.IResourceStreamLocator;
import org.apache.wicket.util.time.Time;


/**
 * An {@link IResourceStream} that reads data from a resource in the classpath. It simply delegates
 * all operations to the {@link IResourceStream} returned by the application's
 * {@link IResourceStreamLocator}.
 * 
 * @author <a href="mailto:jbq@apache.org">Jean-Baptiste Quenot</a>
 */
public class PackageResourceStream extends AbstractResourceStream
{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	IResourceStream resourceStream;

	/**
	 * Obtains an {@link IResourceStream} from the application's
	 * {@link IResourceStreamLocator#locate(Class, String)}
	 * 
	 * @param scope
	 *            This argument will be used to get the class loader for loading the package
	 *            resource, and to determine what package it is in.
	 * @param path
	 *            The path to the resource
	 */
	public PackageResourceStream(Class<?> scope, String path)
	{
		String absolutePath = Packages.absolutePath(scope, path);
		resourceStream = Application.get().getResourceSettings().getResourceStreamLocator().locate(
			scope, absolutePath, null, null, null);

		if (resourceStream == null)
		{
			throw new WicketRuntimeException("Cannot find resource with " + scope.getName() +
				" and path " + path);
		}
	}

	public void close() throws IOException
	{
		resourceStream.close();
	}

	@Override
	public String getContentType()
	{
		return resourceStream.getContentType();
	}

	public InputStream getInputStream() throws ResourceStreamNotFoundException
	{
		return resourceStream.getInputStream();
	}

	@Override
	public long length()
	{
		return resourceStream.length();
	}

	@Override
	public Time lastModifiedTime()
	{
		return resourceStream.lastModifiedTime();
	}
}
